@@ -13,14 +13,14 @@ from .core.initialise import initialise
 from .core.settings import SETTINGS as settings
 from .datasets import Dataset
 from .datasets import get_dataset as dataset  # so the user can do: cml.dataset(...)
-from .datasets import load_dataset, register_dataset
+from .datasets import load_dataset
 from .plotting import interactive_map, new_plot
 from .plotting import options as plotting_options
 from .plotting import plot_graph, plot_map
 from .readers import Reader
 from .sources import Source
 from .sources import get_source as source  # so the user can do: cml.source(...)
-from .sources import load_source, load_source_lazily, register_source
+from .sources import load_source, load_source_lazily
 from .version import __version__
 from .wrappers import Wrapper
 
@@ -42,8 +42,6 @@ __all__ = [
     "settings",
     "source",
     "Source",
-    "register_dataset",
-    "register_source",
     "__version__",
 ]
 
