@@ -14,7 +14,7 @@ from importlib import import_module
 
 from climetlab.core import Base
 from climetlab.core.caching import cache_file
-from climetlab.core.plugins import find_plugin, register
+from climetlab.core.plugins import find_plugin
 from climetlab.core.settings import SETTINGS
 from climetlab.utils.html import table
 
@@ -47,13 +47,20 @@ class Source(Base):
         # Used by multi-source
         return False
 
-    def cache_file(self, *args, **kwargs):
+    def cache_file(self, create, args, **kwargs):
         owner = self.name
         if self.dataset:
             owner = self.dataset.name
         if owner is None:
             owner = re.sub(r"(?!^)([A-Z]+)", r"-\1", self.__class__.__name__).lower()
-        return cache_file(owner, *args, **kwargs)
+
+        resource = None
+        for connection in self.connect_to_mirrors():
+            resource = connection.get_file(create, args)
+        if resource:
+            return resource
+
+        return cache_file(owner, create, args, **kwargs)
 
     @property
     def dataset(self):
@@ -87,6 +94,21 @@ class Source(Base):
     def graph(self, depth=0):
         print(" " * depth, self)
 
+    # Mirroring
+    def connect_to_mirrors(self):
+        result = []
+        from climetlab.mirrors import get_active_mirrors
+
+        for mirror in get_active_mirrors():
+            c = self.connect_to_mirror(mirror)
+            if c is None:
+                continue
+            result.append(c)
+        return result
+
+    def connect_to_mirror(self, mirror):
+        return None
+
 
 class SourceLoader:
 
@@ -130,10 +152,6 @@ class SourceMaker:
 get_source = SourceMaker()
 
 
-def register_source(module):
-    register("source", module)
-
-
 def load_source(name: str, *args, lazily=False, **kwargs) -> Source:
 
     if lazily:
